import React, { PropsWithChildren, ReactNode, ForwardRefExoticComponent, RefAttributes } from 'react';
import { GraphQLSchema, ValidationRule, FragmentDefinitionNode, DocumentNode } from 'graphql';
import { ExecutionContextType } from '@graphiql/react';
import type { EditorContextType, ExplorerContextType, HistoryContextType, ResponseTooltipType, SchemaContextType, StorageContextType, TabsState } from '@graphiql/react';
import { ToolbarButton } from './ToolbarButton';
import { ToolbarGroup } from './ToolbarGroup';
import { ToolbarMenu, ToolbarMenuItem } from './ToolbarMenu';
import { QueryEditor } from './QueryEditor';
import { VariableEditor } from './VariableEditor';
import { HeaderEditor } from './HeaderEditor';
import { ResultViewer } from './ResultViewer';
import type { Fetcher, GetDefaultFieldNamesFn } from '@graphiql/toolkit';
export declare type Maybe<T> = T | null | undefined;
export declare type GraphiQLToolbarConfig = {
    additionalContent?: React.ReactNode;
};
export declare type GraphiQLProps = {
    fetcher: Fetcher;
    schema?: GraphQLSchema | null;
    validationRules?: ValidationRule[];
    query?: string;
    variables?: string;
    headers?: string;
    operationName?: string;
    response?: string;
    storage?: Storage;
    defaultQuery?: string;
    defaultVariableEditorOpen?: boolean;
    defaultSecondaryEditorOpen?: boolean;
    headerEditorEnabled?: boolean;
    shouldPersistHeaders?: boolean;
    externalFragments?: string | FragmentDefinitionNode[];
    onCopyQuery?: (query?: string) => void;
    onEditQuery?: (query?: string, documentAST?: DocumentNode) => void;
    onEditVariables?: (value: string) => void;
    onEditHeaders?: (value: string) => void;
    onEditOperationName?: (operationName: string) => void;
    onToggleDocs?: (docExplorerOpen: boolean) => void;
    getDefaultFieldNames?: GetDefaultFieldNamesFn;
    editorTheme?: string;
    onToggleHistory?: (historyPaneOpen: boolean) => void;
    ResultsTooltip?: ResponseTooltipType;
    dangerouslyAssumeSchemaIsValid?: boolean;
    inputValueDeprecation?: boolean;
    schemaDescription?: boolean;
    introspectionQueryName?: string;
    readOnly?: boolean;
    docExplorerOpen?: boolean;
    toolbar?: GraphiQLToolbarConfig;
    maxHistoryLength?: number;
    onSchemaChange?: (schema: GraphQLSchema) => void;
    beforeTopBarContent?: React.ReactElement | null;
    tabs?: boolean | {
        onTabChange?: (tab: TabsState) => void;
    };
    children?: ReactNode;
};
export declare type GraphiQLState = {
    editorFlex: number;
    secondaryEditorOpen: boolean;
    secondaryEditorHeight: number;
    variableEditorActive: boolean;
    headerEditorActive: boolean;
    headerEditorEnabled: boolean;
    docExplorerWidth: number;
};
export declare const GraphiQL: ForwardRefExoticComponent<GraphiQLProps & RefAttributes<GraphiQLWithContext>> & {
    formatResult(result: any): string;
    formatError(error: any): string;
    Logo: typeof GraphiQLLogo;
    Toolbar: typeof GraphiQLToolbar;
    Footer: typeof GraphiQLFooter;
    QueryEditor: typeof QueryEditor;
    VariableEditor: typeof VariableEditor;
    HeaderEditor: typeof HeaderEditor;
    ResultViewer: typeof ResultViewer;
    Button: typeof ToolbarButton;
    ToolbarButton: typeof ToolbarButton;
    Group: typeof ToolbarGroup;
    Menu: typeof ToolbarMenu;
    MenuItem: typeof ToolbarMenuItem;
};
declare type GraphiQLWithContextProviderProps = Omit<GraphiQLProps, 'dangerouslyAssumeSchemaIsValid' | 'defaultQuery' | 'docExplorerOpen' | 'fetcher' | 'inputValueDeprecation' | 'introspectionQueryName' | 'maxHistoryLength' | 'onToggleDocs' | 'onToggleHistory' | 'query' | 'schema' | 'schemaDescription' | 'storage'>;
declare type GraphiQLWithContextConsumerProps = Omit<GraphiQLWithContextProviderProps, 'fetcher' | 'getDefaultFieldNames' | 'onCopyQuery'> & {
    editorContext: EditorContextType;
    executionContext: ExecutionContextType;
    explorerContext: ExplorerContextType | null;
    historyContext: HistoryContextType | null;
    schemaContext: SchemaContextType;
    storageContext: StorageContextType | null;
    autoCompleteLeafs(): string | undefined;
    copy(): void;
    merge(): void;
    prettify(): void;
};
declare class GraphiQLWithContext extends React.Component<GraphiQLWithContextConsumerProps, GraphiQLState> {
    graphiqlContainer: Maybe<HTMLDivElement>;
    editorBarComponent: Maybe<HTMLDivElement>;
    constructor(props: GraphiQLWithContextConsumerProps);
    componentDidMount(): void;
    render(): JSX.Element;
    getQueryEditor(): import("@graphiql/react/types/editor/context").CodeMirrorEditorWithOperationFacts | null;
    getVariableEditor(): import("@graphiql/react/types/editor/types").CodeMirrorEditor | null;
    getHeaderEditor(): import("@graphiql/react/types/editor/types").CodeMirrorEditor | null;
    refresh(): void;
    autoCompleteLeafs(): string | undefined;
    private handleResizeStart;
    handleResetResize: () => void;
    private _didClickDragBar;
    private handleDocsResizeStart;
    private handleDocsResetResize;
    private handleTabClickPropagation;
    private handleOpenHeaderEditorTab;
    private handleOpenVariableEditorTab;
    private handleSecondaryEditorResizeStart;
}
declare function GraphiQLLogo<TProps>(props: PropsWithChildren<TProps>): JSX.Element;
declare namespace GraphiQLLogo {
    var displayName: string;
}
declare function GraphiQLToolbar<TProps>(props: PropsWithChildren<TProps>): JSX.Element;
declare namespace GraphiQLToolbar {
    var displayName: string;
}
declare function GraphiQLFooter<TProps>(props: PropsWithChildren<TProps>): JSX.Element;
declare namespace GraphiQLFooter {
    var displayName: string;
}
export {};
//# sourceMappingURL=GraphiQL.d.ts.map